@@ -11,28 +11,24 @@
 
 use linuxcnc_hal_sys::*;
 use signal_hook::iterator::Signals;
+use std::convert::TryInto;
 use std::{ffi::CString, mem, thread, time::Duration};
 
 fn main() {
     unsafe {
-        let id = hal_init(CString::new("pins").unwrap().as_ptr() as *const i8);
+        let id = hal_init(CString::new("pins").unwrap().as_ptr().cast());
 
         println!("ID {}", id);
 
         let signals = Signals::new(&[signal_hook::SIGTERM, signal_hook::SIGINT]).unwrap();
 
-        let storage = hal_malloc(mem::size_of::<f64>() as i64) as *mut *mut f64;
+        let storage = hal_malloc(mem::size_of::<*mut f64>().try_into().unwrap()) as *mut *mut f64;
 
         println!("Storage {:?}", storage);
 
         let pin_name = CString::new("pins.input-1").unwrap();
 
-        let ret = hal_pin_float_new(
-            pin_name.as_ptr() as *const i8,
-            hal_pin_dir_t_HAL_IN,
-            storage,
-            id,
-        );
+        let ret = hal_pin_float_new(pin_name.as_ptr().cast(), hal_pin_dir_t_HAL_IN, storage, id);
 
         println!("Pin init {}", ret);
 
