@@ -14,19 +14,15 @@
  *
  *    You should have received a copy of the GNU General Public License
  *    along with this program; if not, write to the Free Software
- *    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 // TODO: reuse interp converters
 
-#define BOOST_PYTHON_MAX_ARITY 7
-#include <boost/python/class.hpp>
-#include <boost/python/def.hpp>
-#include <boost/python/implicit.hpp>
+#include <boost/python.hpp>
 #include <boost/python/module.hpp>
-#include <boost/python/overloads.hpp>
-#include <boost_pyenum_macros.hh>
-#include <boost/python/scope.hpp>
-#include "python_plugin.hh"
+#include <boost/python/class.hpp>
+#include <boost/ref.hpp>
+
 #include "rs274ngc.hh"
 #include "interp_internal.hh"
 #include "taskclass.hh"
@@ -169,10 +165,9 @@ struct TaskWrap : public Task, public bp::wrapper<Task> {
 
 };
 
-typedef pp::array_1_t< EMC_AXIS_STAT, EMCMOT_MAX_AXIS> axis_array, (*axis_w)( EMC_MOTION_STAT &m );
-typedef pp::array_1_t< EMC_SPINDLE_STAT, EMCMOT_MAX_SPINDLES> spindle_array, (*spindle_w)( EMC_MOTION_STAT &m );
-typedef pp::array_1_t< int, EMCMOT_MAX_DIO> synch_dio_array, (*synch_dio_w)( EMC_MOTION_STAT &m );
-typedef pp::array_1_t< double, EMCMOT_MAX_AIO> analog_io_array, (*analog_io_w)( EMC_MOTION_STAT &m );
+typedef pp::array_1_t< EMC_AXIS_STAT, EMC_AXIS_MAX> axis_array, (*axis_w)( EMC_MOTION_STAT &m );
+typedef pp::array_1_t< int, EMC_MAX_DIO> synch_dio_array, (*synch_dio_w)( EMC_MOTION_STAT &m );
+typedef pp::array_1_t< double, EMC_MAX_AIO> analog_io_array, (*analog_io_w)( EMC_MOTION_STAT &m );
 
 typedef pp::array_1_t< int, ACTIVE_G_CODES> active_g_codes_array, (*active_g_codes_tw)( EMC_TASK_STAT &t );
 typedef pp::array_1_t< int, ACTIVE_M_CODES> active_m_codes_array, (*active_m_codes_tw)( EMC_TASK_STAT &t );
@@ -188,10 +183,6 @@ static  axis_array axis_wrapper ( EMC_MOTION_STAT & m) {
     return axis_array(m.axis);
 }
 
-static  spindle_array spindle_wrapper ( EMC_MOTION_STAT & m) {
-    return spindle_array(m.spindle);
-}
-
 static  synch_dio_array synch_di_wrapper ( EMC_MOTION_STAT & m) {
     return synch_dio_array(m.synch_di);
 }
@@ -271,55 +262,58 @@ BOOST_PYTHON_MODULE(emctask) {
 	operator_display_overloads ( args("id"),
 				   "send a message to the operator display"  ));
 
-    BOOST_PYENUM_(RCS_STATUS)
-            .BOOST_PYENUM_VAL(RCS_EXEC)
-            .BOOST_PYENUM_VAL(RCS_DONE)
-            .BOOST_PYENUM_VAL(RCS_ERROR)
-            ;
 
-    BOOST_PYENUM_(EMC_TASK_MODE_ENUM)
-            .BOOST_PYENUM_VAL(EMC_TASK_MODE_MANUAL)
-            .BOOST_PYENUM_VAL(EMC_TASK_MODE_AUTO)
-            .BOOST_PYENUM_VAL(EMC_TASK_MODE_MDI)
-            ;
+#define VAL(X)  .value(#X, X)
 
-    BOOST_PYENUM_(EMC_TASK_STATE_ENUM)
-            .BOOST_PYENUM_VAL(EMC_TASK_STATE_ESTOP)
-            .BOOST_PYENUM_VAL(EMC_TASK_STATE_ESTOP_RESET)
-            .BOOST_PYENUM_VAL(EMC_TASK_STATE_OFF)
-            .BOOST_PYENUM_VAL(EMC_TASK_STATE_ON)
-            ;
+    enum_<RCS_STATUS>("RCS_STATUS")
+	VAL(RCS_EXEC)
+	VAL(RCS_DONE)
+	VAL(RCS_ERROR)
+	;
 
-    BOOST_PYENUM_(EMC_TASK_EXEC_ENUM)
-            .BOOST_PYENUM_VAL(EMC_TASK_EXEC_ERROR)
-            .BOOST_PYENUM_VAL(EMC_TASK_EXEC_DONE)
-            .BOOST_PYENUM_VAL(EMC_TASK_EXEC_WAITING_FOR_MOTION)
-            .BOOST_PYENUM_VAL(EMC_TASK_EXEC_WAITING_FOR_MOTION_QUEUE)
-            .BOOST_PYENUM_VAL(EMC_TASK_EXEC_WAITING_FOR_IO)
-            .BOOST_PYENUM_VAL(EMC_TASK_EXEC_WAITING_FOR_MOTION_AND_IO)
-            .BOOST_PYENUM_VAL(EMC_TASK_EXEC_WAITING_FOR_DELAY)
-            .BOOST_PYENUM_VAL(EMC_TASK_EXEC_WAITING_FOR_SYSTEM_CMD)
-            ;
+    enum_<EMC_TASK_MODE_ENUM>("EMC_TASK_MODE")
+	VAL(EMC_TASK_MODE_MANUAL)
+	VAL(EMC_TASK_MODE_AUTO)
+	VAL(EMC_TASK_MODE_MDI)
+	;
 
-    BOOST_PYENUM_(EMC_TASK_INTERP_ENUM)
-            .BOOST_PYENUM_VAL(EMC_TASK_INTERP_IDLE)
-            .BOOST_PYENUM_VAL(EMC_TASK_INTERP_READING)
-            .BOOST_PYENUM_VAL(EMC_TASK_INTERP_PAUSED)
-            .BOOST_PYENUM_VAL(EMC_TASK_INTERP_WAITING)
-            ;
+    enum_<EMC_TASK_STATE_ENUM>("EMC_TASK_STATE")
+	VAL(EMC_TASK_STATE_ESTOP)
+	VAL(EMC_TASK_STATE_ESTOP_RESET)
+	VAL(EMC_TASK_STATE_OFF)
+	VAL(EMC_TASK_STATE_ON)
+	;
+
+    enum_<EMC_TASK_EXEC_ENUM>("EMC_TASK_EXEC")
+	VAL(EMC_TASK_EXEC_ERROR)
+	VAL(EMC_TASK_EXEC_DONE)
+	VAL(EMC_TASK_EXEC_WAITING_FOR_MOTION)
+	VAL(EMC_TASK_EXEC_WAITING_FOR_MOTION_QUEUE)
+	VAL(EMC_TASK_EXEC_WAITING_FOR_IO)
+	VAL(EMC_TASK_EXEC_WAITING_FOR_MOTION_AND_IO)
+	VAL(EMC_TASK_EXEC_WAITING_FOR_DELAY)
+	VAL(EMC_TASK_EXEC_WAITING_FOR_SYSTEM_CMD)
+	;
+
+    enum_<EMC_TASK_INTERP_ENUM>("EMC_TASK_INTERP")
+	VAL(EMC_TASK_INTERP_IDLE)
+	VAL(EMC_TASK_INTERP_READING)
+	VAL(EMC_TASK_INTERP_PAUSED)
+	VAL(EMC_TASK_INTERP_WAITING)
+	;
 
 
-    BOOST_PYENUM_(EMC_IO_ABORT_REASON_ENUM)
-            .BOOST_PYENUM_VAL(EMC_ABORT_TASK_EXEC_ERROR)
-            .BOOST_PYENUM_VAL(EMC_ABORT_AUX_ESTOP)
-            .BOOST_PYENUM_VAL(EMC_ABORT_MOTION_OR_IO_RCS_ERROR)
-            .BOOST_PYENUM_VAL(EMC_ABORT_TASK_STATE_OFF)
-            .BOOST_PYENUM_VAL(EMC_ABORT_TASK_STATE_ESTOP_RESET)
-            .BOOST_PYENUM_VAL(EMC_ABORT_TASK_STATE_ESTOP)
-            .BOOST_PYENUM_VAL(EMC_ABORT_TASK_STATE_NOT_ON)
-            .BOOST_PYENUM_VAL(EMC_ABORT_TASK_ABORT)
-            .BOOST_PYENUM_VAL(EMC_ABORT_USER)
-            ;
+    enum_<EMC_IO_ABORT_REASON_ENUM>("EMC_IO_ABORT_REASON")
+	VAL(EMC_ABORT_TASK_EXEC_ERROR)
+	VAL(EMC_ABORT_AUX_ESTOP)
+	VAL(EMC_ABORT_MOTION_OR_IO_RCS_ERROR)
+	VAL(EMC_ABORT_TASK_STATE_OFF)
+	VAL(EMC_ABORT_TASK_STATE_ESTOP_RESET)
+	VAL(EMC_ABORT_TASK_STATE_ESTOP)
+	VAL(EMC_ABORT_TASK_STATE_NOT_ON)
+	VAL(EMC_ABORT_TASK_ABORT)
+	VAL(EMC_ABORT_USER)
+	;
 
     class_<TaskWrap, shared_ptr<TaskWrap>, noncopyable >("Task")
 
@@ -328,8 +322,6 @@ BOOST_PYTHON_MODULE(emctask) {
 	.def_readonly("tooltable_filename", &Task::tooltable_filename)
 	;
 
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
     class_ <EMC_TRAJ_STAT, noncopyable>("EMC_TRAJ_STAT",no_init)
 	.def_readwrite("linearUnits", &EMC_TRAJ_STAT::linearUnits )
 	.def_readwrite("angularUnits", &EMC_TRAJ_STAT::angularUnits )
@@ -345,6 +337,7 @@ BOOST_PYTHON_MODULE(emctask) {
 	.def_readwrite("id", &EMC_TRAJ_STAT::id )
 	.def_readwrite("paused", &EMC_TRAJ_STAT::paused )
 	.def_readwrite("scale", &EMC_TRAJ_STAT::scale )
+	.def_readwrite("spindle_scale", &EMC_TRAJ_STAT::spindle_scale )
 	.def_readwrite("position", &EMC_TRAJ_STAT::position )
 	.def_readwrite("actualPosition", &EMC_TRAJ_STAT::actualPosition )
 	.def_readwrite("velocity", &EMC_TRAJ_STAT::velocity )
@@ -361,32 +354,33 @@ BOOST_PYTHON_MODULE(emctask) {
 	.def_readwrite("dtg", &EMC_TRAJ_STAT::dtg )
 	.def_readwrite("current_vel", &EMC_TRAJ_STAT::current_vel )
 	.def_readwrite("feed_override_enabled", &EMC_TRAJ_STAT::feed_override_enabled )
+	.def_readwrite("spindle_override_enabled", &EMC_TRAJ_STAT::spindle_override_enabled )
 	.def_readwrite("adaptive_feed_enabled", &EMC_TRAJ_STAT::adaptive_feed_enabled )
 	.def_readwrite("feed_hold_enabled", &EMC_TRAJ_STAT::feed_hold_enabled )
 	;
-#pragma GCC diagnostic pop
-    class_ <EMC_JOINT_STAT, noncopyable>("EMC_JOINT_STAT",no_init)
-	.def_readwrite("units", &EMC_JOINT_STAT::units)
-	.def_readwrite("backlash", &EMC_JOINT_STAT::backlash)
-	.def_readwrite("minPositionLimit", &EMC_JOINT_STAT::minPositionLimit)
-	.def_readwrite("maxPositionLimit" ,&EMC_JOINT_STAT::maxPositionLimit)
-	.def_readwrite("maxFerror", &EMC_JOINT_STAT::maxFerror)
-	.def_readwrite("minFerror", &EMC_JOINT_STAT::minFerror)
-	.def_readwrite("ferrorCurrent", &EMC_JOINT_STAT::ferrorCurrent)
-	.def_readwrite("ferrorHighMark", &EMC_JOINT_STAT::ferrorHighMark)
-	.def_readwrite("output", &EMC_JOINT_STAT::output)
-	.def_readwrite("input", &EMC_JOINT_STAT::input)
-	.def_readwrite("velocity", &EMC_JOINT_STAT::velocity)
-	.def_readwrite("inpos",  &EMC_JOINT_STAT::inpos)
-	.def_readwrite("homing",  &EMC_JOINT_STAT::homing)
-	.def_readwrite("homed",  &EMC_JOINT_STAT::homed)
-	.def_readwrite("fault",  &EMC_JOINT_STAT::fault)
-	.def_readwrite("enabled",  &EMC_JOINT_STAT::enabled)
-	.def_readwrite("minSoftLimit",  &EMC_JOINT_STAT::minSoftLimit)
-	.def_readwrite("maxSoftLimit",  &EMC_JOINT_STAT::maxSoftLimit)
-	.def_readwrite("minHardLimit",  &EMC_JOINT_STAT::minHardLimit)
-	.def_readwrite("maxHardLimit",  &EMC_JOINT_STAT::maxHardLimit)
-	.def_readwrite("overrideLimits",  &EMC_JOINT_STAT::overrideLimits)
+
+    class_ <EMC_AXIS_STAT, noncopyable>("EMC_AXIS_STAT",no_init)
+	.def_readwrite("units", &EMC_AXIS_STAT::units)
+	.def_readwrite("backlash", &EMC_AXIS_STAT::backlash)
+	.def_readwrite("minPositionLimit", &EMC_AXIS_STAT::minPositionLimit)
+	.def_readwrite("maxPositionLimit" ,&EMC_AXIS_STAT::maxPositionLimit)
+	.def_readwrite("maxFerror", &EMC_AXIS_STAT::maxFerror)
+	.def_readwrite("minFerror", &EMC_AXIS_STAT::minFerror)
+	.def_readwrite("ferrorCurrent", &EMC_AXIS_STAT::ferrorCurrent)
+	.def_readwrite("ferrorHighMark", &EMC_AXIS_STAT::ferrorHighMark)
+	.def_readwrite("output", &EMC_AXIS_STAT::output)
+	.def_readwrite("input", &EMC_AXIS_STAT::input)
+	.def_readwrite("velocity", &EMC_AXIS_STAT::velocity)
+	.def_readwrite("inpos",  &EMC_AXIS_STAT::inpos)
+	.def_readwrite("homing",  &EMC_AXIS_STAT::homing)
+	.def_readwrite("homed",  &EMC_AXIS_STAT::homed)
+	.def_readwrite("fault",  &EMC_AXIS_STAT::fault)
+	.def_readwrite("enabled",  &EMC_AXIS_STAT::enabled)
+	.def_readwrite("minSoftLimit",  &EMC_AXIS_STAT::minSoftLimit)
+	.def_readwrite("maxSoftLimit",  &EMC_AXIS_STAT::maxSoftLimit)
+	.def_readwrite("minHardLimit",  &EMC_AXIS_STAT::minHardLimit)
+	.def_readwrite("maxHardLimit",  &EMC_AXIS_STAT::maxHardLimit)
+	.def_readwrite("overrideLimits",  &EMC_AXIS_STAT::overrideLimits)
 	;
 
     class_ <EMC_SPINDLE_STAT, noncopyable>("EMC_SPINDLE_STAT",no_init)
@@ -395,10 +389,6 @@ BOOST_PYTHON_MODULE(emctask) {
 	.def_readwrite("brake", &EMC_SPINDLE_STAT::brake )
 	.def_readwrite("increasing", &EMC_SPINDLE_STAT::increasing )
 	.def_readwrite("enabled", &EMC_SPINDLE_STAT::enabled )
-	.def_readwrite("spindle_override_enabled", &EMC_SPINDLE_STAT::spindle_override_enabled )
-	.def_readwrite("spindle_scale", &EMC_SPINDLE_STAT::spindle_scale )
-	.def_readwrite("spindle_orient_state", &EMC_SPINDLE_STAT::orient_state )
-	.def_readwrite("spindle_orient_fault", &EMC_SPINDLE_STAT::orient_fault )
 	;
 
     class_ <EMC_COOLANT_STAT , noncopyable>("EMC_COOLANT_STAT ",no_init)
@@ -416,9 +406,9 @@ BOOST_PYTHON_MODULE(emctask) {
 	.add_property( "axis",
 		       bp::make_function( axis_w(&axis_wrapper),
 					  bp::with_custodian_and_ward_postcall< 0, 1 >()))
-	.add_property( "spindle",
-			   bp::make_function( spindle_w(&spindle_wrapper),
-					  bp::with_custodian_and_ward_postcall< 0, 1 >()))
+
+
+	.def_readwrite("spindle", &emcStatus->motion.spindle)
 	.add_property( "synch_di",
 		       bp::make_function( synch_dio_w(&synch_di_wrapper),
 					  bp::with_custodian_and_ward_postcall< 0, 1 >()))
@@ -510,9 +500,9 @@ BOOST_PYTHON_MODULE(emctask) {
 
     implicitly_convertible<EMC_TASK_STATE_ENUM, int>();
 
-    pp::register_array_1< double, EMCMOT_MAX_AIO> ("AnalogIoArray");
-    pp::register_array_1< int, EMCMOT_MAX_DIO> ("DigitalIoArray");
-    pp::register_array_1< EMC_AXIS_STAT,EMCMOT_MAX_AXIS,
+    pp::register_array_1< double, EMC_MAX_AIO> ("AnalogIoArray");
+    pp::register_array_1< int, EMC_MAX_DIO> ("DigitalIoArray");
+    pp::register_array_1< EMC_AXIS_STAT,EMC_AXIS_MAX,
 	bp::return_internal_reference< 1, bp::default_call_policies > > ("AxisArray");
 }
 
