@@ -317,27 +317,6 @@ int tcGetEndTangentUnitVector(TC_STRUCT const * const tc, PmCartesian * const ou
     return 0;
 }
 
-
-
-/**
- * Calculate the distance left in the trajectory segment in the indicated
- * direction.
- */
-double tcGetDistanceToGo(TC_STRUCT const * const tc, int direction)
-{
-    double distance = tcGetTarget(tc, direction) - tc->progress;
-    if (direction == TC_DIR_REVERSE) {
-        distance *=-1.0;
-    }
-    return distance;
-}
-
-double tcGetTarget(TC_STRUCT const * const tc, int direction)
-{
-    return (direction == TC_DIR_REVERSE) ? 0.0 : tc->target;
-}
-
-
 /*! tcGetPos() function
  *
  * \brief This function calculates the machine position along the motion's path.
@@ -637,7 +616,7 @@ int tcInit(TC_STRUCT * const tc,
     tc->id = -1; //ID to be set when added to queue (may change before due to blend arcs)
 
     /** Segment settings (given values later during setup / optimization) */
-    tc->indexer_jnum = -1;
+    tc->indexrotary = -1;
 
     tc->active_depth = 1;
 
@@ -825,8 +804,7 @@ int tcUpdateTargetFromCircle(TC_STRUCT * const tc)
 
 int pmRigidTapInit(PmRigidTap * const tap,
         EmcPose const * const start,
-        EmcPose const * const end,
-        double reversal_scale)
+        EmcPose const * const end)
 {
     PmCartesian start_xyz, end_xyz;
     PmCartesian abc, uvw;
@@ -844,7 +822,6 @@ int pmRigidTapInit(PmRigidTap * const tap,
 
     // Setup initial tap state
     tap->reversal_target = tap->xyz.tmag;
-    tap->reversal_scale = reversal_scale;
     tap->state = TAPPING;
     return TP_ERR_OK;
 
