@@ -25,8 +25,6 @@
 *
 ********************************************************************/
 
-#define JOGMODE   JOGJOINT  
-
 #include <stdio.h>
 #include <string.h>
 #include <sys/stat.h>
@@ -1133,43 +1131,43 @@ static void parseConnect()
 //  sockSendStr(sockfd, "info\n");
 }
 
-static int jog(int jnum, float speed)
+static int jog(int axis, float speed)
 {
   float stepSize;
 
   if (emcStatus->task.mode != EMC_TASK_MODE_MANUAL) return 0;
   if (units == unmm) stepSize = 10.0;
   else stepSize = 1.0;
-  if ((jnum < 0) || (jnum > 5)) return -1;
+  if ((axis < 0) || (axis > 5)) return -1;
 //  if (runStatus == rsIdle) {
 //    sendManual();
     switch (jogMode) {
       case jtCont: 
         if (jogging == 1) {  // toggle if driver does not support key down / key up
           jogging = 0;
-          return sendJogStop(jnum, JOGMODE);
+          return sendJogStop(axis);
           }
         else {
           jogging = 1;
-          return sendJogCont(jnum, JOGMODE, speed);
+          return sendJogCont(axis, speed);
           }
-      case jtStep1: return sendJogIncr(jnum, JOGMODE, speed, stepSize/conversion); break;
-      case jtStep01: return sendJogIncr(jnum, JOGMODE, speed, (stepSize/10.0)/conversion); break;
-      case jtStep001: return sendJogIncr(jnum, JOGMODE, speed, (stepSize/100.0)/conversion); break;
-      case jtStep0001: return sendJogIncr(jnum, JOGMODE, speed, (stepSize/1000.0)/conversion); break;
+      case jtStep1: return sendJogIncr(axis, speed, stepSize/conversion); break;
+      case jtStep01: return sendJogIncr(axis, speed, (stepSize/10.0)/conversion); break;
+      case jtStep001: return sendJogIncr(axis, speed, (stepSize/100.0)/conversion); break;
+      case jtStep0001: return sendJogIncr(axis, speed, (stepSize/1000.0)/conversion); break;
       default: return -1;
       }
 //    }
 //  else return 0;
 }
 
-static int jogStop(int jnum)
+static int jogStop(int axis)
 {
   if (emcStatus->task.mode != EMC_TASK_MODE_MANUAL) return 0;
-  if ((jnum < 0) || (jnum > 5)) return -1;
+  if ((axis < 0) || (axis > 5)) return -1;
   jogging = 0;
   if (jogMode != jtCont) return 0;
-  return sendJogStop(jnum, JOGMODE);
+  return sendJogStop(axis);
 }
 
 static int leftKey()
