@@ -21,11 +21,9 @@
 
 /* You should have received a copy of the GNU Lesser General Public */
 /* License along with this library; if not, write to the Free Software */
-/* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
+/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+
 
-#include <locale.h>
-#include <libintl.h>
-#define _(x) gettext(x)
 #include <gtk/gtk.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -143,57 +141,57 @@ void LoadElementProperties(StrElement * Element)
 			case ELE_OUTPUT_SET:
 			case ELE_OUTPUT_RESET:
 				strcpy(TextToWrite,CreateVarName(Element->VarType,Element->VarNum));
-				SetProperty(0,_("Variable"),TextToWrite);
+				SetProperty(0,"Variable",TextToWrite);
 				break;
 			case ELE_OUTPUT_JUMP:
-				SetProperty(0,_("JumpToLabel"),RungArray[Element->VarNum].Label);
+				SetProperty(0,"JumpToLabel",RungArray[Element->VarNum].Label);
 				break;
 			case ELE_OUTPUT_CALL:
 				sprintf(TextToWrite,"%d",Element->VarNum);
-				SetProperty(0,_("Sub-Routine"),TextToWrite);
+				SetProperty(0,"Sub-Routine",TextToWrite);
 				break;
 #ifdef OLD_TIMERS_MONOS_SUPPORT
 			case ELE_TIMER:
 				Timer = &TimerArray[Element->VarNum];
 				sprintf(TextToWrite,"%d",Element->VarNum);
-				SetProperty(0,_("TimerNbr"),TextToWrite);
+				SetProperty(0,"TimerNbr",TextToWrite);
 				sprintf(TextToWrite,"%s",CorresDatasForBase[ ConvBaseInMilliSecsToId(Timer->Base) ].ParamSelect);
-				SetProperty(1,_("Base"),TextToWrite);
+				SetProperty(1,"Base",TextToWrite);
 				sprintf(TextToWrite,"%d",Timer->Preset/Timer->Base);
-				SetProperty(2,_("Preset"),TextToWrite);
+				SetProperty(2,"Preset",TextToWrite);
 				break;
 			case ELE_MONOSTABLE:
 				Monostable = &MonostableArray[Element->VarNum];
 				sprintf(TextToWrite,"%d",Element->VarNum);
-				SetProperty(0,_("MonostNbr"),TextToWrite);
+				SetProperty(0,"MonostNbr",TextToWrite);
 				sprintf(TextToWrite,"%s",CorresDatasForBase[ ConvBaseInMilliSecsToId(Monostable->Base) ].ParamSelect);
-				SetProperty(1,_("Base"),TextToWrite);
+				SetProperty(1,"Base",TextToWrite);
 				sprintf(TextToWrite,"%d",Monostable->Preset/Monostable->Base);
-				SetProperty(2,_("Preset"),TextToWrite);
+				SetProperty(2,"Preset",TextToWrite);
 				break;
 #endif
 			case ELE_COUNTER:
 				Counter = &CounterArray[Element->VarNum];
 				sprintf(TextToWrite,"%d",Element->VarNum);
-				SetProperty(0,_("CounterNbr"),TextToWrite);
+				SetProperty(0,"CounterNbr",TextToWrite);
 				sprintf(TextToWrite,"%d",Counter->Preset);
-				SetProperty(1,_("Preset"),TextToWrite);
+				SetProperty(1,"Preset",TextToWrite);
 				break;
 			case ELE_TIMER_IEC:
 				TimerIEC = &NewTimerArray[Element->VarNum];
 				sprintf(TextToWrite,"%d",Element->VarNum);
-				SetProperty(0,_("TimerNbr"),TextToWrite);
+				SetProperty(0,"TimerNbr",TextToWrite);
 				sprintf(TextToWrite,"%s",CorresDatasForBase[ ConvBaseInMilliSecsToId(TimerIEC->Base) ].ParamSelect);
-				SetProperty(1,_("Base"),TextToWrite);
+				SetProperty(1,"Base",TextToWrite);
 				sprintf(TextToWrite,"%d",TimerIEC->Preset);
-				SetProperty(2,_("Preset"),TextToWrite);
+				SetProperty(2,"Preset",TextToWrite);
 				sprintf(TextToWrite,"%s",TimersModesStrings[ (int)TimerIEC->TimerMode ]);
-				SetProperty(3,_("TimerMode"),TextToWrite);
+				SetProperty(3,"TimerMode",TextToWrite);
 				break;
 			case ELE_COMPAR:
 			case ELE_OUTPUT_OPERATE:
 				strcpy(TextToWrite,DisplayArithmExpr(EditArithmExpr[Element->VarNum].Expr,0));
-				SetProperty(0,_("Expression"),TextToWrite);
+				SetProperty(0,"Expression",TextToWrite);
 				break;
 		}
 	}
@@ -223,35 +221,35 @@ char * GetElementPropertiesForStatusBar(StrElement * Element)
 			case ELE_OUTPUT_NOT:
 			case ELE_OUTPUT_SET:
 			case ELE_OUTPUT_RESET:				
-				sprintf(PropertiesText, _("Variable: %s    Hal sig: %s"),CreateVarName(Element->VarType,Element->VarNum),ConvVarNameToHalSigName(CreateVarName(Element->VarType,Element->VarNum)));
+				sprintf(PropertiesText, "Variable: %s    Hal sig: %s",CreateVarName(Element->VarType,Element->VarNum),ConvVarNameToHalSigName(CreateVarName(Element->VarType,Element->VarNum)));
 				break;
 			case ELE_OUTPUT_JUMP:
-				sprintf(PropertiesText, _("Label: %s"), RungArray[Element->VarNum].Label);
+				sprintf(PropertiesText, "Label: %s", RungArray[Element->VarNum].Label);
 				break;
 			case ELE_OUTPUT_CALL:
-				sprintf(PropertiesText, _("Sub-Routine: %d"), Element->VarNum);
+				sprintf(PropertiesText, "Sub-Routine: %d", Element->VarNum);
 				break;
 #ifdef OLD_TIMERS_MONOS_SUPPORT
 			case ELE_TIMER:
 				Timer = &TimerArray[Element->VarNum];
-				sprintf(PropertiesText, _("%cT%d: Preset=%d Base=%s"), '%', Element->VarNum, Timer->Preset/Timer->Base, CorresDatasForBase[ ConvBaseInMilliSecsToId(Timer->Base) ].ParamSelect);
+				sprintf(PropertiesText, "%cT%d: Preset=%d Base=%s", '%', Element->VarNum, Timer->Preset/Timer->Base, CorresDatasForBase[ ConvBaseInMilliSecsToId(Timer->Base) ].ParamSelect);
 				break;
 			case ELE_MONOSTABLE:
 				Monostable = &MonostableArray[Element->VarNum];
-				sprintf(PropertiesText, _("%cM%d: Preset=%d Base=%s"), '%', Element->VarNum, Monostable->Preset/Monostable->Base, CorresDatasForBase[ ConvBaseInMilliSecsToId(Monostable->Base) ].ParamSelect);
+				sprintf(PropertiesText, "%cM%d: Preset=%d Base=%s", '%', Element->VarNum, Monostable->Preset/Monostable->Base, CorresDatasForBase[ ConvBaseInMilliSecsToId(Monostable->Base) ].ParamSelect);
 				break;
 #endif
 			case ELE_COUNTER:
 				Counter = &CounterArray[Element->VarNum];
-				sprintf(PropertiesText, _("%cC%d: Preset=%d"), '%', Element->VarNum, Counter->Preset);
+				sprintf(PropertiesText, "%cC%d: Preset=%d", '%', Element->VarNum, Counter->Preset);
 				break;
 			case ELE_TIMER_IEC:
 				TimerIEC = &NewTimerArray[Element->VarNum];
-				sprintf(PropertiesText, _("%cTM%d: Preset=%d Base=%s Mode=%s"), '%', Element->VarNum, TimerIEC->Preset, CorresDatasForBase[ ConvBaseInMilliSecsToId(TimerIEC->Base) ].ParamSelect, TimersModesStrings[ (int)TimerIEC->TimerMode ]);
+				sprintf(PropertiesText, "%cTM%d: Preset=%d Base=%s Mode=%s", '%', Element->VarNum, TimerIEC->Preset, CorresDatasForBase[ ConvBaseInMilliSecsToId(TimerIEC->Base) ].ParamSelect, TimersModesStrings[ (int)TimerIEC->TimerMode ]);
 				break;
 			case ELE_COMPAR:
 			case ELE_OUTPUT_OPERATE:
-				sprintf(PropertiesText,_("HAL sig: %s"),FirstVariableInArithm(DisplayArithmExpr(ArithmExpr[Element->VarNum].Expr,0)));
+				sprintf(PropertiesText,"HAL sig: %s",FirstVariableInArithm(DisplayArithmExpr(ArithmExpr[Element->VarNum].Expr,0)));
 							
 				break;
 		}
@@ -348,7 +346,7 @@ char * TextParserForArithmExpr(char * text, int TypeElement)
 
 				{
 					ItIsOk = FALSE;
-					ErrorMessageVarParser = _("Incompatible type of variable (must be an integer!)");
+					ErrorMessageVarParser = "Incompatible type of variable (must be an integer!)";
 				}
 			}
 			else
@@ -387,9 +385,9 @@ char * TextParserForArithmExpr(char * text, int TypeElement)
 		if (strlen(NewExpr)>=ARITHM_EXPR_SIZE-1)
 		{
 			NewExpr[ ARITHM_EXPR_SIZE-1 ] = '\0';
-			printf(_("New expr=%s\n"), NewExpr );
+			printf("New expr=%s\n", NewExpr );
 			ItIsOk = FALSE;
-			ErrorMessageVarParser = _("Expression too long");
+			ErrorMessageVarParser = "Expression too long";
 		}
 	}
 //printf("Parser Arithm ; ItIsOk=%d ; OriExpr=%s ; NewExpr=%s\n",ItIsOk, text, NewExpr);
@@ -406,7 +404,7 @@ char * TextParserForArithmExpr(char * text, int TypeElement)
 	/* Error Message */
 	if (ErrorMessageVarParser)
 	{
-		ShowMessageBox(_("Error"),ErrorMessageVarParser,_("Ok"));
+		ShowMessageBox("Error",ErrorMessageVarParser,"Ok");
 	}
 	/* Give result */
 	if (ItIsOk)
@@ -456,7 +454,7 @@ void SaveElementProperties()
 					if ( !TEST_VAR_IS_A_BOOL( VarTypeEntered,VarNumEntered ) )
 
 					{
-						ShowMessageBox(_("Error"),_("You must select a boolean variable !"),_("Ok"));
+						ShowMessageBox("Error","You must select a boolean variable !","Ok");
 					}
 					else
 					{
@@ -467,9 +465,9 @@ void SaveElementProperties()
 				else
 				{
 					if (ErrorMessageVarParser)
-						ShowMessageBox(_("Error"),ErrorMessageVarParser,_("Ok"));
+						ShowMessageBox("Error",ErrorMessageVarParser,"Ok");
 					else
-						ShowMessageBox( _("Error"), _("Unknown variable..."), _("Ok") );
+						ShowMessageBox( "Error", "Unknown variable...", "Ok" );
 				}
 				break;
 #ifdef OLD_TIMERS_MONOS_SUPPORT
@@ -1078,7 +1076,7 @@ void GetSizesOfAnElement(short int NumEle,int * pSizeX, int * pSizeY)
 	}
 	if ( NumEle>=EDIT_CNX_WITH_TOP )
 	{
-		printf(_("!!!Abnormal current type=%d in rung...(file %s,line %d)\n"), NumEle, __FILE__, __LINE__ );
+		printf("!!!Abnormal current type=%d in rung...(file %s,line %d)\n", NumEle, __FILE__, __LINE__ );
 		*pSizeX = 0;
 		*pSizeY = 0;
 	}
@@ -1168,7 +1166,7 @@ void EditElementInRung(double x,double y)
 						//TODO: better error handling here (not creating element after...)
 						if ( EditDatas.Rung.Element[RungX][RungY].VarNum==-1 )
 						{
-							ShowMessageBox( _("Error"), _("No more free function block available...please delete!"), _("Ok") );
+							ShowMessageBox( "Error", "No more free function block available...please delete!", "Ok" );
 							EditDatas.Rung.Element[RungX][RungY].VarNum = 0;
 						}
 						SetUsedStateFunctionBlock( NumElement, EditDatas.Rung.Element[RungX][RungY].VarNum, TRUE );
