@@ -18,11 +18,8 @@
 
 /* You should have received a copy of the GNU Lesser General Public */
 /* License along with this library; if not, write to the Free Software */
-/* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
+/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
 
-#include <locale.h>
-#include <libintl.h>
-#define _(x) gettext(x)
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
@@ -116,7 +113,7 @@ char * CreateVarName(int Type, int Offset)
 			sprintf(Buffer,"???");
 			break;
 	}
-printf(_("infogene display symbols=&i\n"),InfosGene->DisplaySymbols);
+printf("infogene display symbols=&i\n",InfosGene->DisplaySymbols);
 	if ( InfosGene->DisplaySymbols )
 	{ 
 		// verify if a symbol has been defined for the variable...
@@ -174,7 +171,7 @@ char TextParserForAVar( char * text,int * VarTypeFound,int * VarOffsetFound, int
 		if ( VarNameFromSymbol==NULL )
 		{
 			IsOk = FALSE;
-			ErrorMessageVarParser = _("Unknown symbol for variable name");
+			ErrorMessageVarParser = "Unknown symbol for variable name";
 		}
 		else
 		{
@@ -194,7 +191,7 @@ char TextParserForAVar( char * text,int * VarTypeFound,int * VarOffsetFound, int
 				if (!TextToNumberAndAdvance(pPtrScanPos,0,NBR_BITS-1,&OffsetFound))
 				{
 					IsOk = FALSE;
-					ErrorMessageVarParser = _("Unknown variable (number value out of bound)");
+					ErrorMessageVarParser = "Unknown variable (number value out of bound)";
 				}
 				break;
 	
@@ -216,7 +213,7 @@ char TextParserForAVar( char * text,int * VarTypeFound,int * VarOffsetFound, int
 				if (!TextToNumberAndAdvance(pPtrScanPos,0,MaxNbr,&OffsetFound))
 				{
 					IsOk = FALSE;
-					ErrorMessageVarParser = _("Unknown variable (number value out of bound)");
+					ErrorMessageVarParser = "Unknown variable (number value out of bound)";
 				}
 				else
 				{
@@ -225,7 +222,7 @@ char TextParserForAVar( char * text,int * VarTypeFound,int * VarOffsetFound, int
 						if ( **pPtrScanPos!=VAR_ATTRIBUTE_SEP )
 						{
 							IsOk = FALSE;
-							ErrorMessageVarParser = _("Unknown variable (missing '.' character before attribute)");
+							ErrorMessageVarParser = "Unknown variable (missing '.' character before attribute)";
 						}
 						else
 						{
@@ -240,7 +237,7 @@ char TextParserForAVar( char * text,int * VarTypeFound,int * VarOffsetFound, int
 									else
 									{
 										IsOk = FALSE;
-										ErrorMessageVarParser = _("Unknown variable (unknown attribute)");
+										ErrorMessageVarParser = "Unknown variable (unknown attribute)";
 									}
 									break;
 								case 'Q':
@@ -251,7 +248,7 @@ char TextParserForAVar( char * text,int * VarTypeFound,int * VarOffsetFound, int
 									else
 									{
 										IsOk = FALSE;
-										ErrorMessageVarParser = _("Unknown variable (unknown attribute)");
+										ErrorMessageVarParser = "Unknown variable (unknown attribute)";
 									}
 									break;
 								case 'R':
@@ -262,7 +259,7 @@ char TextParserForAVar( char * text,int * VarTypeFound,int * VarOffsetFound, int
 									else
 									{
 										IsOk = FALSE;
-										ErrorMessageVarParser = _("Unknown variable (unknown attribute)");
+										ErrorMessageVarParser = "Unknown variable (unknown attribute)";
 									}
 									break;
 								case 'P':
@@ -273,7 +270,7 @@ char TextParserForAVar( char * text,int * VarTypeFound,int * VarOffsetFound, int
 									break;
 								default:
 									IsOk = FALSE;
-									ErrorMessageVarParser = _("Unknown variable (unknown attribute)");
+									ErrorMessageVarParser = "Unknown variable (unknown attribute)";
 									break;
 							}
 							(*pPtrScanPos)++;
@@ -288,7 +285,7 @@ char TextParserForAVar( char * text,int * VarTypeFound,int * VarOffsetFound, int
 				if (!TextToNumberAndAdvance(pPtrScanPos,0,NBR_MONOSTABLES-1,&OffsetFound))
 				{
 					IsOk = FALSE;
-					ErrorMessageVarParser = _("Unknown variable (number value out of bound)");
+					ErrorMessageVarParser = "Unknown variable (number value out of bound)";
 				}
 				else
 				{
@@ -297,7 +294,7 @@ char TextParserForAVar( char * text,int * VarTypeFound,int * VarOffsetFound, int
 						if ( **pPtrScanPos!=VAR_ATTRIBUTE_SEP )
 						{
 							IsOk = FALSE;
-							ErrorMessageVarParser = _("Unknown variable (missing '.' character before attribute)");
+							ErrorMessageVarParser = "Unknown variable (missing '.' character before attribute)";
 						}
 						else
 						{
@@ -315,7 +312,7 @@ char TextParserForAVar( char * text,int * VarTypeFound,int * VarOffsetFound, int
 									break;
 								default:
 									IsOk = FALSE;
-									ErrorMessageVarParser = _("Unknown variable (unknown attribute)");
+									ErrorMessageVarParser = "Unknown variable (unknown attribute)";
 									break;
 							}
 							(*pPtrScanPos)++;
@@ -330,7 +327,7 @@ char TextParserForAVar( char * text,int * VarTypeFound,int * VarOffsetFound, int
 				if (!TextToNumberAndAdvance(pPtrScanPos,0,NBR_COUNTERS-1,&OffsetFound))
 				{
 					IsOk = FALSE;
-					ErrorMessageVarParser = _("Unknown variable (number value out of bound)");
+					ErrorMessageVarParser = "Unknown variable (number value out of bound)";
 				}
 				else
 				{
@@ -339,7 +336,7 @@ char TextParserForAVar( char * text,int * VarTypeFound,int * VarOffsetFound, int
 						if ( **pPtrScanPos!=VAR_ATTRIBUTE_SEP )
 						{
 							IsOk = FALSE;
-							ErrorMessageVarParser = _("Unknown variable (missing '.' character before attribute)");
+							ErrorMessageVarParser = "Unknown variable (missing '.' character before attribute)";
 						}
 						else
 						{
@@ -363,7 +360,7 @@ char TextParserForAVar( char * text,int * VarTypeFound,int * VarOffsetFound, int
 									break;
 								default:
 									IsOk = FALSE;
-									ErrorMessageVarParser = _("Unknown variable (unknown attribute)");
+									ErrorMessageVarParser = "Unknown variable (unknown attribute)";
 									break;
 							}
 							(*pPtrScanPos)++;
@@ -378,7 +375,7 @@ char TextParserForAVar( char * text,int * VarTypeFound,int * VarOffsetFound, int
 				if (!TextToNumberAndAdvance(pPtrScanPos,0,NBR_PHYS_INPUTS-1,&OffsetFound))
 				{
 					IsOk = FALSE;
-					ErrorMessageVarParser = _("Unknown variable (number value out of bound)");
+					ErrorMessageVarParser = "Unknown variable (number value out of bound)";
 				}
 				break;
 	
@@ -388,7 +385,7 @@ char TextParserForAVar( char * text,int * VarTypeFound,int * VarOffsetFound, int
 				if (!TextToNumberAndAdvance(pPtrScanPos,0,NBR_PHYS_OUTPUTS-1,&OffsetFound))
 				{
 					IsOk = FALSE;
-					ErrorMessageVarParser = _("Unknown variable (number value out of bound)");
+					ErrorMessageVarParser = "Unknown variable (number value out of bound)";
 				}
 				break;
 	
@@ -398,7 +395,7 @@ char TextParserForAVar( char * text,int * VarTypeFound,int * VarOffsetFound, int
 				if (!TextToNumberAndAdvance(pPtrScanPos,0,NBR_WORDS-1,&OffsetFound))
 				{
 					IsOk = FALSE;
-					ErrorMessageVarParser = _("Unknown variable (number value out of bound)");
+					ErrorMessageVarParser = "Unknown variable (number value out of bound)";
 				}
 				break;
 	
@@ -409,7 +406,7 @@ char TextParserForAVar( char * text,int * VarTypeFound,int * VarOffsetFound, int
 				if (!TextToNumberAndAdvance(pPtrScanPos,0,NBR_STEPS-1,&OffsetFound))
 				{
 					IsOk = FALSE;
-					ErrorMessageVarParser = _("Unknown variable (number value out of bound)");
+					ErrorMessageVarParser = "Unknown variable (number value out of bound)";
 				}
 				else
 				{
@@ -425,7 +422,7 @@ char TextParserForAVar( char * text,int * VarTypeFound,int * VarOffsetFound, int
 						else
 						{
 							IsOk = FALSE;
-							ErrorMessageVarParser = _("Unknown variable (unknown attribute)");
+							ErrorMessageVarParser = "Unknown variable (unknown attribute)";
 						}
 					}
 				}
@@ -434,7 +431,7 @@ char TextParserForAVar( char * text,int * VarTypeFound,int * VarOffsetFound, int
 	
 			default:
 				IsOk = FALSE;
-				ErrorMessageVarParser = _("Unknown variable (on first character following %)");
+				ErrorMessageVarParser = "Unknown variable (on first character following %)";
 		}
 		if (IsOk)
 		{
@@ -448,7 +445,7 @@ char TextParserForAVar( char * text,int * VarTypeFound,int * VarOffsetFound, int
 		else
 		{
 			if ( ErrorMessageVarParser==NULL )
-				ErrorMessageVarParser = _("Unknown variable (global error)");
+				ErrorMessageVarParser = "Unknown variable (global error)";
 		}
 	}
 	return IsOk;
@@ -617,7 +614,7 @@ char TextParserForAVar( char * TextToParse, int * VarTypeFound,int * VarOffsetFo
 				bVerifCoherenceOk = FALSE;
 		}
 		if ( bVerifCoherenceOk==FALSE )
-			ErrorMessageVarParser = _("Unknown variable (number value out of bound)");
+			ErrorMessageVarParser = "Unknown variable (number value out of bound)";
 
 		if (bVerifCoherenceOk)
 		{
