@@ -106,7 +106,7 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111 USA
  *
  * THE AUTHORS OF THIS LIBRARY ACCEPT ABSOLUTELY NO LIABILITY FOR
  * ANY HARM OR LOSS RESULTING FROM ITS USE.  IT IS _EXTREMELY_ UNWISE
@@ -416,11 +416,10 @@ Device_Init(Device *this, MotencRegMap *pCard)
 	this->numFpga = 1;
     } else {
 	// No idea what it is.
-	this->boardType = 2;
+	this->boardType = 0;
 	this->pTypeName = "unknown";
-	rtapi_print_msg(RTAPI_MSG_ERR, "MOTENC: unknown board type - %i\n", status);
 	this->numFpga = 0;
-	//return -1;
+	return -1;
     }
 
     // Extract board id from first FPGA. The user sets this via jumpers on the card.
