@@ -22,6 +22,11 @@
 
 #include <rtapi_list.h>
 
+// please God where do these live in real life?
+#define INT32_MIN (-2147483647-1)
+#define INT32_MAX (2147483647)
+#define UINT32_MAX (4294967295U)
+
 #include "rtapi.h"
 #include "hal.h"
 #include "sserial.h"
@@ -98,8 +103,6 @@
 #define HM2_GTAG_SSI               (8)
 #define HM2_GTAG_UART_TX           (9)
 #define HM2_GTAG_UART_RX           (10)
-#define HM2_GTAG_PKTUART_TX        (27)  // PktUART uses same addresses as normal UART with 
-#define HM2_GTAG_PKTUART_RX        (28) // the assumption you would not use both in one config
 #define HM2_GTAG_TRANSLATIONRAM    (11)
 #define HM2_GTAG_MUXED_ENCODER     (12)
 #define HM2_GTAG_MUXED_ENCODER_SEL (13)
@@ -116,17 +119,12 @@
 #define HM2_GTAG_BISS              (24) 
 #define HM2_GTAG_FABS              (25) 
 #define HM2_GTAG_HM2DPLL           (26) 
-#define HM2_GTAG_INMUX             (30) 
-#define HM2_GTAG_INM               (35) 
-#define HM2_GTAG_DPAINTER          (42) 
-#define HM2_GTAG_XY2MOD            (43) 
 #define HM2_GTAG_LIOPORT           (64) // Not supported
 #define HM2_GTAG_LED               (128)
 
 #define HM2_GTAG_RESOLVER          (192)
 #define HM2_GTAG_SMARTSERIAL       (193)
 #define HM2_GTAG_TWIDDLER          (194) // Not supported
-#define HM2_GTAG_SSR               (195)
 
 
 
@@ -273,7 +271,6 @@ typedef struct {
             hal_float_t *position;
             hal_float_t *position_latch;
             hal_float_t *velocity;
-            hal_float_t *velocity_rpm;
             hal_bit_t *reset;
             hal_bit_t *index_enable;
             hal_bit_t *latch_enable;
@@ -417,18 +414,15 @@ typedef struct {
             hal_float_t *angle;
             hal_float_t *position;
             hal_float_t *velocity;
-            hal_float_t *velocity_rpm;
             hal_bit_t *reset;
             hal_bit_t *index_enable;
             hal_bit_t *error;
-            hal_float_t *joint_pos_fb;
         } pin;
 
         struct {
             hal_float_t scale;
             hal_float_t vel_scale;
             hal_u32_t index_div;
-            hal_bit_t use_abs;
         } param;
 
     } hal;
@@ -497,8 +491,7 @@ typedef struct {
 
         struct {
             hal_float_t scale;
-            hal_bit_t offset_mode;
-            hal_s32_t output_type; 
+            hal_s32_t output_type;
         } param;
 
     } hal;
@@ -507,10 +500,6 @@ typedef struct {
     // know if we need to update it
     rtapi_s32 written_output_type;
 
-    // this keeps track of the offset_mode that we've set , so we
-    // know if we need to update it
-    rtapi_s32 written_offset_mode;
-
     // this keeps track of the enable bit for this instance that we've told
     // the FPGA, so we know if we need to update it
     rtapi_s32 written_enable;
@@ -562,285 +551,6 @@ typedef struct {
     rtapi_u32 enable_reg;  // one register for the whole Function
 } hm2_pwmgen_t;
 
-//
-// inmux
-// 
-
-
-typedef struct {
-
-    struct {
-
-        struct {
-            hal_bit_t *filt_data[32];
-            hal_bit_t *raw_data[32];
-            hal_bit_t *filt_data_not[32];
-            hal_bit_t *raw_data_not[32];
-            hal_bit_t *slow[32] ;
-            hal_s32_t *enc0_count; 
-            hal_s32_t *enc1_count; 
-            hal_s32_t *enc2_count; 
-            hal_s32_t *enc3_count; 		
-        } pin;
-
-        struct {
-            hal_u32_t scan_rate;
-            hal_u32_t slow_scans; 
-            hal_u32_t fast_scans; 		
-            hal_bit_t enc0_mode; 
-            hal_bit_t enc1_mode; 
-            hal_bit_t enc2_mode; 
-            hal_bit_t enc3_mode; 
-            hal_u32_t scan_width; 	    	
-        } param;
-
-    } hal;
-
-    //scanwidth for this instance	
-    rtapi_u32 scanwidth;	
-
-    //previous MPG counts for this instance	
-    rtapi_s8 prev_enc0_count;	
-    rtapi_s8 prev_enc1_count;	
-    rtapi_s8 prev_enc2_count;	
-    rtapi_s8 prev_enc3_count;	
-
-    // this keeps track of the control register that we've told the FPGA, so we
-    // know if we need to update it
-    rtapi_u32 written_control_reg;
-
-    // this keeps track of the filter register that we've told the FPGA, so we
-    // know if we need to update it
-    rtapi_u32 written_filter_reg;
-
-    // this keeps track of the mpg mode register that we've told the FPGA, so we
-    // know if we need to update it
-    rtapi_u32 written_mpg_mode_reg;
-
-} hm2_inmux_instance_t;
-
-
-
-typedef struct {
-    int num_instances;
-    hm2_inmux_instance_t *instance;
-
-    rtapi_u32 clock_frequency;
-    rtapi_u8 version;
-
-
-    // module-global HAL objects...
-
-    rtapi_u32 control_addr;
-    rtapi_u32 *control_reg;
-
-    rtapi_u32 filter_addr;
-    rtapi_u32 *filter_reg;
-
-    rtapi_u32 filt_data_addr;
-    rtapi_u32 *filt_data_reg; 
-
-    rtapi_u32 raw_data_addr;
-    rtapi_u32 *raw_data_reg; 
-
-    rtapi_u32 mpg_read_addr;
-    rtapi_u32 *mpg_read_reg;  
-
-    rtapi_u32 mpg_mode_addr;
-    rtapi_u32 *mpg_mode_reg; 
-
-} hm2_inmux_t;
-
-
-//
-// inm   basicall a clone of InMux
-// 
-
-
-typedef struct {
-
-    struct {
-
-        struct {
-            hal_bit_t *filt_data[32];
-            hal_bit_t *raw_data[32];
-            hal_bit_t *filt_data_not[32];
-            hal_bit_t *raw_data_not[32];
-            hal_bit_t *slow[32] ;
-            hal_s32_t *enc0_count; 
-            hal_s32_t *enc1_count; 
-            hal_s32_t *enc2_count; 
-            hal_s32_t *enc3_count; 		
-        } pin;
-
-        struct {
-            hal_u32_t scan_rate;
-            hal_u32_t slow_scans; 
-            hal_u32_t fast_scans; 		
-            hal_bit_t enc0_mode; 
-            hal_bit_t enc1_mode; 
-            hal_bit_t enc2_mode; 
-            hal_bit_t enc3_mode; 
-            hal_u32_t scan_width; 	    	
-        } param;
-
-    } hal;
-
-    //scanwidth for this instance	
-    rtapi_u32 scanwidth;	
-
-    //previous MPG counts for this instance	
-    rtapi_s8 prev_enc0_count;	
-    rtapi_s8 prev_enc1_count;	
-    rtapi_s8 prev_enc2_count;	
-    rtapi_s8 prev_enc3_count;	
-
-    // this keeps track of the control register that we've told the FPGA, so we
-    // know if we need to update it
-    rtapi_u32 written_control_reg;
-
-    // this keeps track of the filter register that we've told the FPGA, so we
-    // know if we need to update it
-    rtapi_u32 written_filter_reg;
-
-    // this keeps track of the mpg mode register that we've told the FPGA, so we
-    // know if we need to update it
-    rtapi_u32 written_mpg_mode_reg;
-
-} hm2_inm_instance_t;
-
-
-
-typedef struct {
-    int num_instances;
-    hm2_inm_instance_t *instance;
-
-    rtapi_u32 clock_frequency;
-    rtapi_u8 version;
-
-
-    // module-global HAL objects...
-
-    rtapi_u32 control_addr;
-    rtapi_u32 *control_reg;
-
-    rtapi_u32 filter_addr;
-    rtapi_u32 *filter_reg;
-
-    rtapi_u32 filt_data_addr;
-    rtapi_u32 *filt_data_reg; 
-
-    rtapi_u32 raw_data_addr;
-    rtapi_u32 *raw_data_reg; 
-
-    rtapi_u32 mpg_read_addr;
-    rtapi_u32 *mpg_read_reg;  
-
-    rtapi_u32 mpg_mode_addr;
-    rtapi_u32 *mpg_mode_reg; 
-
-} hm2_inm_t;
-
-
-//
-// xy2mod
-// 
-
-
-typedef struct {
-
-    struct {
-
-        struct {
-            hal_float_t *accx_cmd;
-            hal_float_t *accy_cmd;
-            hal_float_t *velx_cmd;
-            hal_float_t *vely_cmd;
-            hal_float_t *posx_cmd;
-            hal_float_t *posy_cmd;
-            hal_float_t *velx_fb;
-            hal_float_t *vely_fb;
-            hal_float_t *posx_fb;
-            hal_float_t *posy_fb;
-            hal_float_t *posx_scale;
-            hal_float_t *posy_scale;
-            hal_bit_t 	*enable;
-            hal_bit_t 	*controlx0;
-            hal_bit_t 	*controlx1;
-            hal_bit_t 	*controlx2;
-            hal_bit_t 	*controly0;
-            hal_bit_t 	*controly1;
-            hal_bit_t 	*controly2;
-            hal_bit_t 	*status;
-            hal_bit_t 	*posx_overflow;
-            hal_bit_t 	*posy_overflow;
-            hal_bit_t 	*velx_overflow;
-            hal_bit_t 	*vely_overflow;
-        } pin;
-
-    } hal;
-
-
-    //previous MPG counts for this instance	
-    hal_float_t prev_accx_cmd;	
-    hal_float_t prev_accy_cmd;	
-    hal_float_t prev_velx_cmd;	
-    hal_float_t prev_vely_cmd;	
-    hal_float_t prev_posx_cmd;	
-    hal_float_t prev_posy_cmd;	
-
- 
-} hm2_xy2mod_instance_t;
-
-// these hal params affect all xy2mod instances
-typedef struct {
-    struct {
-        hal_s32_t *dpll_timer_num;
-    } pin;
-} hm2_xy2mod_module_global_t;
-
-
-typedef struct {
-    int num_instances;
-    hm2_xy2mod_instance_t *instance;
-
-    rtapi_u32 clock_frequency;
-    rtapi_u8 version;
-
-
-    // module-global HAL objects...
-
-    hm2_xy2mod_module_global_t *hal;
-    rtapi_u32 written_dpll_timer_num;
-
-
-    rtapi_u32 accx_addr;
-    rtapi_u32 *accx_reg;
-
-    rtapi_u32 accy_addr;
-    rtapi_u32 *accy_reg;
-
-    rtapi_u32 velx_addr;
-    rtapi_u32 *velx_reg;
-
-    rtapi_u32 vely_addr;
-    rtapi_u32 *vely_reg;
-
-    rtapi_u32 posx_addr;
-    rtapi_u32 *posx_reg;
-
-    rtapi_u32 posy_addr;
-    rtapi_u32 *posy_reg;
-
-    rtapi_u32 mode_addr;
-    rtapi_u32 *mode_reg;
-
-    rtapi_u32 dpll_timer_num_addr;
-    rtapi_u32 *dpll_timer_num_reg;
-
-
-} hm2_xy2mod_t;
-
 
 //
 // 3-Phase pwmgen
@@ -872,9 +582,9 @@ typedef struct {
     // know if an update-write is needed
     // enable is a little more complicated and is based on the read-back
     // of the fault/enable register
-    double written_deadzone;
+    float written_deadzone;
     int written_faultpolarity;
-    double written_sampletime;
+    float written_sampletime;
 } hm2_tp_pwmgen_instance_t;
 
 typedef struct {
@@ -1060,9 +770,7 @@ typedef struct {
     rtapi_u32 dpll_timer_num_addr;
 } hm2_stepgen_t;
 
-
-
-//galv
+//
 // Buffered SPI transciever
 // 
 
@@ -1125,32 +833,6 @@ typedef struct {
     rtapi_u8 num_registers;
 } hm2_uart_t;
 
-//
-// PktUART
-// 
-
-typedef struct {
-    rtapi_u32 clock_freq;
-    rtapi_u32 bitrate;
-    rtapi_u32 tx_fifo_count_addr;
-    rtapi_u32 tx_bitrate_addr;
-    rtapi_u32 tx_addr;
-    rtapi_u32 tx_mode_addr;
-    rtapi_u32 rx_fifo_count_addr;
-    rtapi_u32 rx_bitrate_addr;
-    rtapi_u32 rx_addr;
-    rtapi_u32 rx_mode_addr;
-    char name[HAL_NAME_LEN+1];
-} hm2_pktuart_instance_t;
-
-typedef struct {
-    int version;
-    int num_instances;
-    hm2_pktuart_instance_t *instance;
-    rtapi_u8 instances;
-    rtapi_u8 num_registers;
-    struct rtapi_heap *heap;
-} hm2_pktuart_t;
 //
 // HM2DPLL
 //
@@ -1255,39 +937,6 @@ typedef struct {
 } hm2_led_t ;
 
 
-//
-// SSR
-//
-
-typedef struct {
-    struct {
-
-        struct {
-            hal_u32_t *rate;
-            hal_bit_t *out[32];
-        } pin;
-
-    } hal;
-
-    rtapi_u32 written_data;
-    rtapi_u32 written_rate;
-} hm2_ssr_instance_t;
-
-typedef struct {
-    int num_instances;
-    hm2_ssr_instance_t *instance;
-
-    rtapi_u8 version;
-    rtapi_u32 clock_freq;
-
-    rtapi_u32 data_addr;
-    rtapi_u32 *data_reg;
-
-    rtapi_u32 rate_addr;
-    rtapi_u32 *rate_reg;
-} hm2_ssr_t;
-
-
 // 
 // raw peek/poke access
 //
@@ -1344,12 +993,7 @@ typedef struct {
         int num_sserials;
         int num_bspis;
         int num_uarts;
-        int num_pktuarts;
         int num_dplls;
-        int num_inmuxs;
-        int num_inms;
-        int num_xy2mods;
-        int num_ssrs;
         char sserial_modes[4][8];
         int enable_raw;
         char *firmware;
@@ -1388,15 +1032,10 @@ typedef struct {
     hm2_sserial_t sserial;
     hm2_bspi_t bspi;
     hm2_uart_t uart;
-    hm2_pktuart_t pktuart;
     hm2_ioport_t ioport;
     hm2_watchdog_t watchdog;
     hm2_dpll_t dpll;
-    hm2_inmux_t inmux;
-    hm2_inm_t inm;
-    hm2_xy2mod_t xy2mod;
     hm2_led_t led;
-    hm2_ssr_t ssr;
 
     hm2_raw_t *raw;
 
@@ -1439,7 +1078,6 @@ void hm2_print_modules(hostmot2_t *hm2);
 hm2_sserial_remote_t *hm2_get_sserial(hostmot2_t **hm2, char *name);
 int hm2_get_bspi(hostmot2_t **hm2, char *name);
 int hm2_get_uart(hostmot2_t **hm2, char *name);
-int hm2_get_pktuart(hostmot2_t **hm2, char *name);
 
 
 //
@@ -1589,6 +1227,7 @@ void hm2_sserial_setmode(hostmot2_t *hm2, hm2_sserial_instance_t *inst);
 int hm2_sserial_create_pins(hostmot2_t *hm2, hm2_sserial_remote_t *chan);
 int hm2_sserial_register_tram(hostmot2_t *hm2, hm2_sserial_remote_t *chan);
 int hm2_sserial_read_configs(hostmot2_t *hm2, hm2_sserial_remote_t *chan);
+void hm2_sserial_setmode(hostmot2_t *hm2, hm2_sserial_instance_t *inst);
 
 //
 // Buffered SPI functions
@@ -1605,9 +1244,8 @@ int hm2_allocate_bspi_tram(char* name);
 int hm2_bspi_write_chan(char* name, int chan, rtapi_u32 val);
 int hm2_allocate_bspi_tram(char* name);
 int hm2_tram_add_bspi_frame(char *name, int chan, rtapi_u32 **wbuff, rtapi_u32 **rbuff);
-int hm2_bspi_setup_chan(char *name, int chan, int cs, int bits, double mhz,
-                        int delay, int cpol, int cpha, int noclear, int noecho,
-                        int samplelate);
+int hm2_bspi_setup_chan(char *name, int chan, int cs, int bits, float mhz, 
+                        int delay, int cpol, int cpha, int clear, int echo);
 int hm2_bspi_set_read_function(char *name, int (*func)(void *subdata), void *subdata);
 int hm2_bspi_set_write_function(char *name, int (*func)(void *subdata), void *subdata);
 
@@ -1625,70 +1263,17 @@ void hm2_uart_process_tram_read(hostmot2_t *hm2, long period);
 int hm2_uart_setup(char *name, int bitrate, rtapi_s32 tx_mode, rtapi_s32 rx_mode);
 int hm2_uart_send(char *name, unsigned char data[], int count);
 int hm2_uart_read(char *name, unsigned char data[]);
-//
-// PktUART functions
-//
-
-int  hm2_pktuart_parse_md(hostmot2_t *hm2, int md_index);
-void hm2_pktuart_print_module(hostmot2_t *hm2);
-void hm2_pktuart_cleanup(hostmot2_t *hm2);
-void hm2_pktuart_write(hostmot2_t *hm2);
-void hm2_pktuart_force_write(hostmot2_t *hm2); // ?? 
-void hm2_pktuart_prepare_tram_write(hostmot2_t *hm2, long period); //??
-void hm2_pktuart_process_tram_read(hostmot2_t *hm2, long period);  //  ??
-int hm2_pktuart_setup(char *name, int bitrate, rtapi_s32 tx_mode, rtapi_s32 rx_mode, int txclear, int rxclear);
-int hm2_pktuart_send(char *name,  unsigned char data[], rtapi_u8 *num_frames, rtapi_u16 frame_sizes[]);
-int hm2_pktuart_read(char *name, unsigned char data[],  rtapi_u8 *num_frames, rtapi_u16 *max_frame_length, rtapi_u16 frame_sizes[]);
 
 //
 // hm2dpll functions
 //
 
 void hm2_dpl_cleanup(hostmot2_t *hm2);
+int hm2_dpll_force_write(hostmot2_t *hm2);
 int hm2_dpll_parse_md(hostmot2_t *hm2, int md_index);
 void hm2_dpll_process_tram_read(hostmot2_t *hm2, long period);
 void hm2_dpll_write(hostmot2_t *hm2, long period);
 
-
-//
-// InMux functions
-//
-
-int  hm2_inmux_parse_md(hostmot2_t *hm2, int md_index);
-void hm2_inmux_print_module(hostmot2_t *hm2);
-void hm2_inmux_cleanup(hostmot2_t *hm2);
-void hm2_inmux_write(hostmot2_t *hm2);
-void hm2_inmux_force_write(hostmot2_t *hm2);
-void hm2_inmux_prepare_tram_write(hostmot2_t *hm2);
-void hm2_inmux_queue_read(hostmot2_t *hm2);
-void hm2_inmux_process_tram_read(hostmot2_t *hm2);
-
-//
-// InM functions
-//
-
-int  hm2_inm_parse_md(hostmot2_t *hm2, int md_index);
-void hm2_inm_print_module(hostmot2_t *hm2);
-void hm2_inm_cleanup(hostmot2_t *hm2);
-void hm2_inm_write(hostmot2_t *hm2);
-void hm2_inm_force_write(hostmot2_t *hm2);
-void hm2_inm_prepare_tram_write(hostmot2_t *hm2);
-void hm2_inm_queue_read(hostmot2_t *hm2);
-void hm2_inm_process_tram_read(hostmot2_t *hm2);
-
-//
-// xy2mod functions
-//
-
-int  hm2_xy2mod_parse_md(hostmot2_t *hm2, int md_index);
-void hm2_xy2mod_print_module(hostmot2_t *hm2);
-void hm2_xy2mod_cleanup(hostmot2_t *hm2);
-void hm2_xy2mod_write(hostmot2_t *hm2);
-void hm2_xy2mod_force_write(hostmot2_t *hm2);
-void hm2_xy2mod_queue_read(hostmot2_t *hm2);
-void hm2_xy2mod_process_tram_read(hostmot2_t *hm2);
-
-
 // 
 // watchdog functions
 // 
@@ -1712,19 +1297,6 @@ int hm2_led_parse_md(hostmot2_t *hm2, int md_index);
 void hm2_led_write(hostmot2_t *hm2);
 void hm2_led_cleanup(hostmot2_t *hm2);
 
-
-//
-// SSR functions
-//
-
-int hm2_ssr_parse_md(hostmot2_t *hm2, int md_index);
-void hm2_ssr_cleanup(hostmot2_t *hm2);
-void hm2_ssr_write(hostmot2_t *hm2);
-void hm2_ssr_force_write(hostmot2_t *hm2);
-void hm2_ssr_prepare_tram_write(hostmot2_t *hm2);
-void hm2_ssr_print_module(hostmot2_t *hm2);
-
-
 //
 // the raw interface lets you peek and poke the hostmot2 instance from HAL
 //
@@ -1740,8 +1312,4 @@ void hm2_raw_write(hostmot2_t *hm2);
 // used by hm2_register() to initialize and by hm2_pet_watchdog() to recover from io errors and watchdog errors
 void hm2_force_write(hostmot2_t *hm2);
 
-
-// items related to pin naming
-const char *hm2_get_general_function_hal_name(int gtag);
-const char *hm2_get_pin_secondary_hal_name(const hm2_pin_t *pin);
 #endif
