@@ -17,7 +17,7 @@
 
     You should have received a copy of the GNU General Public
     License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111 USA
 
     THE AUTHORS OF THIS LIBRARY ACCEPT ABSOLUTELY NO LIABILITY FOR
     ANY HARM OR LOSS RESULTING FROM ITS USE.  IT IS _EXTREMELY_ UNWISE
@@ -45,7 +45,6 @@
 #include <string.h>
 
 #include "rtapi.h"		/* RTAPI realtime OS API */
-#include <rtapi_mutex.h>
 #include "hal.h"		/* HAL public API decls */
 #include "../hal_priv.h"	/* private HAL decls */
 
@@ -971,7 +970,7 @@ static gboolean search_for_entry(GtkWidget *widget, GdkEventKey *event, dialog_g
 	search_row = search_row + 1;
 	if(!gtk_clist_get_text(clist, search_row, 0, &text))
 	    search_row = 0;
-	printf(_("next search: %d\n"), search_row);
+	printf("next search: %d\n", search_row);
     } else {
 	strcat(search_target, event->string);
     }
@@ -979,7 +978,7 @@ static gboolean search_for_entry(GtkWidget *widget, GdkEventKey *event, dialog_g
     for(z = search_row, wrapped=0; z != search_row || !wrapped; z ++) {
 	char *text;
 
-	printf(_("search: %d (wrapped=%d)\n"), z, wrapped);
+	printf("search: %d (wrapped=%d)\n", z, wrapped);
 	if(!gtk_clist_get_text(clist, z, 0, &text)) {
 	    if(wrapped) break; // wrapped second time (why?)
 	    z = 0;
