@@ -193,7 +193,6 @@ CMS::CMS(const char *bufline_in, const char *procline_in, int set_to_server)
     int i;
     min_compatible_version = 0;
     force_raw = 0;
-    serial = 0;
     confirm_write = 0;
     disable_final_write_raw_for_dma = 0;
     /* Init string buffers */
@@ -207,7 +206,7 @@ CMS::CMS(const char *bufline_in, const char *procline_in, int set_to_server)
     memset(proclineupper, 0, CMS_CONFIG_LINELEN);
     memset(PermissionString, 0, CMS_CONFIG_LINELEN);
 
-    /* Initialize some variables. */
+    /* Initailize some variables. */
     read_permission_flag = 0;	/* Allow both read and write by default.  */
     write_permission_flag = 0;
     queuing_enabled = 0;
@@ -419,11 +418,6 @@ CMS::CMS(const char *bufline_in, const char *procline_in, int set_to_server)
 	    continue;
 	}
 
-	if (!strcmp(word[i], "SERIAL")) {
-	    serial = 1;
-	    continue;
-	}
-
 	if (!strcmp(word[i], "CONFIRM_WRITE")) {
 	    confirm_write = 1;
 	    continue;
