@@ -103,6 +103,92 @@ IniFile::Close()
 }
 
 
+IniFile::ErrorCode                   
+IniFile::Find(int *result, int min, int max,
+              const char *tag, const char *section, int num)
+{
+    ErrorCode                   errCode;
+    int                         tmp;
+
+    if((errCode = Find(&tmp, tag, section, num)) != ERR_NONE)
+        return(errCode);
+
+    if((tmp > max) || (tmp < min))
+        return(ERR_LIMITS);
+
+    *result = tmp;
+
+    return(ERR_NONE);
+}
+
+
+IniFile::ErrorCode                   
+IniFile::Find(int *result, const char *tag, const char *section, int num)
+{
+    const char                  *pStr;
+    int                         tmp;
+
+    if((pStr = Find(tag, section, num)) == NULL){
+        // We really need an ErrorCode return from Find() and should be passing
+        // in a buffer. Just pick a suitable ErrorCode for now.
+        return(ERR_TAG_NOT_FOUND);
+    }
+
+    if(sscanf(pStr, "%i", &tmp) != 1){
+        ThrowException(ERR_CONVERSION);
+        return(ERR_CONVERSION);
+    }
+
+    *result = tmp;
+
+    return(ERR_NONE);
+}
+
+
+IniFile::ErrorCode                   
+IniFile::Find(double *result, double min, double max,
+              const char *tag, const char *section, int num)
+{
+    ErrorCode                   errCode;
+    double                      tmp;
+
+    if((errCode = Find(&tmp, tag, section, num)) != ERR_NONE)
+        return(errCode);
+
+    if((tmp > max) || (tmp < min))
+        return(ERR_LIMITS);
+
+    *result = tmp;
+
+    return(ERR_NONE);
+}
+
+
+IniFile::ErrorCode                   
+IniFile::Find(double *result, const char *tag, const char *section,
+	      int num, int *lineno)
+{
+    const char                  *pStr;
+    double                      tmp;
+
+    if((pStr = Find(tag, section, num)) == NULL){
+        // We really need an ErrorCode return from Find() and should be passing
+        // in a buffer. Just pick a suitable ErrorCode for now.
+        return(ERR_TAG_NOT_FOUND);
+    }
+
+    if(sscanf(pStr, "%lf", &tmp) != 1){
+        ThrowException(ERR_CONVERSION);
+        return(ERR_CONVERSION);
+    }
+
+    *result = tmp;
+    if (lineno)
+	*lineno = lineNo;
+    return(ERR_NONE);
+}
+
+
 IniFile::ErrorCode
 IniFile::Find(int *result, StrIntPair *pPair,
      const char *tag, const char *section, int num, int *lineno)
@@ -292,7 +378,7 @@ IniFile::Find(const char *_tag, const char *_section, int _num, int *lineno)
             line[newLinePos] = 0;        /* make the newline 0 */
         }
         // honor backslash (\) as line-end escape
-        if (newLinePos > 0 && line[newLinePos-1] == '\\') {
+        if (line[newLinePos-1] == '\\') {
            newLinePos = newLinePos-1;
            line[newLinePos] = 0;
            if (!extend_ct) {
