@@ -43,7 +43,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this library; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111 USA
 */
 
 /** THE AUTHORS OF THIS LIBRARY ACCEPT ABSOLUTELY NO LIABILITY FOR
@@ -83,14 +83,13 @@
 #include <rtai_fifos.h>
 
 #include "rtapi.h"		/* public RTAPI decls */
-#include <rtapi_mutex.h>
 #include "rtapi_common.h"	/* shared realtime/nonrealtime stuff */
 
 #ifndef RTAI_NR_TRAPS
 #define RTAI_NR_TRAPS HAL_NR_FAULTS
 #endif
 
-#if RTAI < 5
+#if RTAI <= 3
 #define rt_free_timers rt_free_timer
 #endif
 
